@@ -26,6 +26,8 @@
 defined('MOODLE_INTERNAL') || die();
 
 $string['pluginname'] = 'Objectives report';
+$string['privacy:metadata:preference:scorm_report_objectives_score'] = 'Whether to display the objective score in the SCORM report';
+$string['privacy:metadata:preference:scorm_report_pagesize'] = 'Number of users to display in the SCORM reports';
 $string['objectivex'] = 'Objective {$a}';
 $string['objectivescore'] = 'Show objective score';
 $string['score'] = 'score';
